@@ -78,9 +78,9 @@ void init_encryption(key_text)
     char *key_text;
 {
     des_cblock key_bin;
-    
-    des_string_to_key(key_text, key_bin);
-    des_set_key(key_bin, sched);
+
+    des_string_to_key(key_text, &key_bin);
+    des_set_key(&key_bin, sched);
 }
 
 char *make_packet(uid, laddr, lport, faddr, fport)
@@ -156,10 +156,10 @@ void init_decryption(key_file)
     
     while (fgets(buf, 1024, key_file) != NULL && num_keys < MAX_KEYS)
     {
-	des_string_to_key(buf, keys[num_keys++]);
+	des_string_to_key(buf, &keys[num_keys++]);
     }
     
-    des_set_key (keys [0], sched);
+    des_set_key (&keys [0], sched);
 }
 
 
@@ -176,7 +176,7 @@ char *decrypt_packet(packet)
     for (k = -1; k < num_keys; k++)
     {
 	if (k >= 0)
-	    des_set_key(keys [k], sched);
+	    des_set_key(&keys [k], sched);
 	
 	for(i = 0, j = 0; i < 24; i+=3, j+=4)
 	{
