@@ -196,7 +196,7 @@ char *gethost(addr)
 	    for (i = 0; hp->h_addr_list[i]; i++)
 		if (comparemem(hp->h_addr_list[i],
 			       (unsigned char *) addr,
-			       sizeof(struct in_addr)) == 0)
+			       (int) sizeof(struct in_addr)) == 0)
 		    return (char *) hp->h_name;
 #else
 	if (comparemem(hp->h_addr, addr, sizeof(struct in_addr)) == 0)
@@ -236,10 +236,13 @@ child_handler()
 #else
     int status;
 #endif
-
+    int saved_errno = errno;
+    
     while (wait3(&status, WNOHANG, NULL) > 0)
 	;
-  
+
+    errno = saved_errno;
+    
 #ifndef SIGRETURN_TYPE_IS_VOID
     return 0;
 #endif
@@ -382,6 +385,11 @@ int main(argc,argv)
 	    
 	  case 'l':    /* Use the Syslog daemon for logging */
 	    syslog_flag++;
+#ifdef LOG_DAEMON
+	    openlog("identd", LOG_PID, syslog_facility);
+#else
+	    openlog("identd", LOG_PID);
+#endif
 	    break;
 	    
 	  case 'o':
@@ -549,7 +557,7 @@ int main(argc,argv)
 	if (fd != 0)
 	    dup2(fd, 0);
 	
-	clearmem(&addr, sizeof(addr));
+	clearmem((void *) &addr, (int) sizeof(addr));
 	
 	addr.sin_family = AF_INET;
 	if (bind_address == NULL)
@@ -754,23 +762,12 @@ int main(argc,argv)
     faddr = sin.sin_addr;
     
     
-    /*
-    ** Open the connection to the Syslog daemon if requested
-    */
-    if (syslog_flag)
-    {
-#ifdef LOG_DAEMON
-	openlog("identd", LOG_PID, syslog_facility);
-#else
-	openlog("identd", LOG_PID);
-#endif
-
 #ifdef STRONG_LOG
+    if (syslog_flag)
 	syslog(LOG_INFO, "Connection from %s", gethost(&faddr));
 #endif
-    }
-  
 
+    
     /*
     ** Get local internet address
     */
